==> haskell-doctest-0.16.0.1-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctest
version: 0.16.0.1
id: doctest-0.16.0.1-H5V2zZNtwar9fjTXhhjlrd
key: doctest-0.16.0.1-H5V2zZNtwar9fjTXhhjlrd
license: MIT
copyright: (c) 2009-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/doctest#readme
synopsis: Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<http://docs.python.org/library/doctest.html>).
    .
    Documentation is at <https://github.com/sol/doctest#readme>.
category: Testing
abi: a71122ebfa080a8ab94fb18cabb744d9
exposed: True
exposed-modules:
    Test.DocTest
hidden-modules: Extract GhcUtil Interpreter Location Options
                PackageDBs Parse Property Run Runner Runner.Example Sandbox Util
                Language.Haskell.GhciWrapper Paths_doctest
import-dirs: /usr/lib/ghc-8.6.3/site-local/doctest-0.16.0.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/doctest-0.16.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/doctest-0.16.0.1
hs-libraries: HSdoctest-0.16.0.1-H5V2zZNtwar9fjTXhhjlrd
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    code-page-0.2-3TjNtc9lu3RJN6poyFdQXs deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1 ghc-8.6.3
    ghc-paths-0.1.0.9-KaBYbRV3ryA10w04FwbrO2 process-1.6.3.0
    syb-0.7-KRW1LCxdMiCJrmhxCvzo37 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-doctest/html/doctest.haddock
haddock-html: /usr/share/doc/haskell-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-0.16.0.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctest
version: 0.16.0.1
id: doctest-0.16.0.1-Dg19OrZhx9EHJhiQFeEB0e
key: doctest-0.16.0.1-Dg19OrZhx9EHJhiQFeEB0e
license: MIT
copyright: (c) 2009-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/doctest#readme
synopsis: Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<http://docs.python.org/library/doctest.html>).
    .
    Documentation is at <https://github.com/sol/doctest#readme>.
category: Testing
abi: e0b379cb921c4538c72300b252e6608f
exposed: True
exposed-modules:
    Test.DocTest
hidden-modules: Extract GhcUtil Interpreter Location Options
                PackageDBs Parse Property Run Runner Runner.Example Sandbox Util
                Language.Haskell.GhciWrapper Paths_doctest
import-dirs: /usr/lib/ghc-8.6.3/site-local/doctest-0.16.0.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/doctest-0.16.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/doctest-0.16.0.1
hs-libraries: HSdoctest-0.16.0.1-Dg19OrZhx9EHJhiQFeEB0e
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    code-page-0.2-3TjNtc9lu3RJN6poyFdQXs deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1 ghc-8.6.3
    ghc-paths-0.1.0.9-KaBYbRV3ryA10w04FwbrO2 process-1.6.3.0
    syb-0.7-KRW1LCxdMiCJrmhxCvzo37 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-doctest/html/doctest.haddock
haddock-html: /usr/share/doc/haskell-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
